---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: onuratakan

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Use this code:
```python
PUT_YOUR_CODE_TO_HERE
```
2. Run with this command
```console

```

4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. Windows]
 - Upsonic Version [e.g. 0.48.0]
- Python Version [e.g. 3.11]


**Additional context**
Add any other context about the problem here.
